@@ -1,15 +1,16 @@
-import logging
 import uuid
 from itertools import groupby
+from collections import OrderedDict
 
 
 from .api import SquadApi, ApiException
 from squad_client.exceptions import InvalidSquadObject, InvalidSquadLookup
 from squad_client.utils import first, parse_test_name, parse_metric_name, to_json, get_class_name
 from squad_client import settings
+from squad_client import logging
 
 
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 
 DEFAULT_COUNT = settings.DEFAULT_NUM_OF_OBJECTS
 ALL = -1
@@ -55,10 +56,6 @@ class SquadObject:
         if obj is None:
             obj = self
 
-        nested_endpoints = [x[1] for x in SquadApi.schema_nested_eps if x[0].lower() == get_class_name(obj).lower()]
-        if nested_endpoints:
-            setattr(obj, 'nested_endpoints', nested_endpoints)
-
         attrs = obj.attrs if len(obj.attrs) else [attr for attr in result.keys()]
         for attr in attrs:
             if attr in result.keys():
@@ -387,13 +384,15 @@ class Build(SquadObject):
 
         return testruns
 
-    __tests__ = None
+    __tests__ = {}
 
     def tests(self, count=ALL, **filters):
-        if self.__tests__ is None:
+        filters['count'] = count
+        filters_str = str(OrderedDict(filters))
+        if self.__tests__.get(filters_str) is None:
             endpoint = '%s%d/tests/' % (self.endpoint, self.id)
-            self.__tests__ = self.__fetch__(Test, filters, count, endpoint=endpoint)
-        return self.__tests__
+            self.__tests__[filters_str] = self.__fetch__(Test, filters, count, endpoint=endpoint)
+        return self.__tests__[filters_str]
 
     __metadata__ = None
     __status__ = None
